# Installation Steps

Follow the instruction steps below to install Apache Pulsar Messaging Service in Kubernetes environment.

1. Replacing Placeholders: 
There are placeholders present in different files which needs to be replaced with actual value based on the environment where the installation is happening.

Placeholder  | Description
------------ | -------------
%KUBERNETESNODE1% | the Kubernetes node name for the first Pulsar node (replace 3 times in file pv3.yaml)
%KUBERNETESNODE2% | the Kubernetes node name for the second Pulsar node (replace 3 times in file pv3.yaml)
%KUBERNETESNODE3% | the Kubernetes node name for the third Pulsar node (replace 3 times in file pv3.yaml)
%DOCKERREPOSITORYIMAGE% | the docker registry image path (replace multiple times in file pulsar/values.yaml)
%DOCKERPEPOSITORYZOOKEEPERIMAGE% | the docker registry image path (replace in file pulsar/values.yaml)

> There is a handy python3 script named *localize.py* which can be used to do the above substitutions.

2. Creating directories in Kubernetes nodes

Apache Pulsar will be installed on 3 Kubernetes nodes and Pulsar components uses local storage under /var/zookeeper and /var/bookie for persistence in each node.

> Persistent volumes is defined in file pv3.yaml and requires 130GiB disk space in total 

On each Kubernetes worker nodes where the Apache Pulsar pods gets deployed
```
mkdir /var/zookeeper
mkdir -p /var/bookie/journal
mkdir -p /var/bookie/ledgers
```

> If the folders already exists and if you want a fresh installation, clear files and folders inside /var/zookeeper, /var/bookie/journal, /var/bookie/ledgers on each kubernetes worker nodes.

3. Copy this helm chart to the kubernetes master node (or other node with KUBECONFIG env var set up)
```
cd pulsar
```

4. Create namespace
```
kubectl create namespace c8y-messaging-service
```

5. Create the public/private key pair used by notifications 2.0 for both Core pods and Pulsar websocket proxy pods.

Use "kubekctl get namespaces" or "kubectl get pods -A" to find the namespace that Core pods are deployed in if you don't already know the namespace name". Use this namespace name as an argument to the c8y_create_secrets.sh script in the pulsar-helm-chart directory. If the Core pods have been deployed in the default namespace then the argument can be omitted otherwise it must be given.

First make sure that Core is going to use the same key by deleting it if it already exists:
```
kubectl delete secret c8y-messaging-secret -n <your-c8y-namespace-for-core-pods>
```

Then run the script to generate the key pair and create the secrets:
```
./c8y_create_secrets.sh <your-c8y-namespace-for-core-pods>
```

A public/private key pair is created and made available as a kubernetes secret for core pods and the public key is made avaiable to Pulsar web socket proxy pods.

6. Create image pull secret:
```
kubectl create secret docker-registry imagesecret -n c8y-messaging-service --docker-server=%REGISTRY% --docker-username=%REGISTRYUSERNAME% --docker-password=%REGISTRYPASSWORD% --docker-email=%REGISTRYEMAIL%
```

Placeholder  | Description
------------ | -------------
%REGISTRY% | the url of a Docker registry containing the c8y-pulsar image (replace in commands in this file)
%REGISTRYUSERNAME% | the username for the Docker registry (replace in commands in this file)
%REGISTRYPASSWORD% | the password for the Docker registry (replace in commands in this file)
%REGISTRYEMAIL% | the email of a Docker registry administrator (replace in commands in this file)


7. Create local PVs
```
kubectl -n c8y-messaging-service apply -f pv3.yaml
```

8. Deploy pulsar chart
```
cd ..
helm install --values pulsar/values.yaml pulsar --set initialize=true ./pulsar
```
> initialize=true to initialize the pulsar cluster - first time only / when not upgrading)

7. Verify the installation
```
helm list -A
helm status pulsar
kubectl get pods -n c8y-messaging-service
```

Open a terminal and run the following: 
```
kubectl exec -it pulsar-broker-0 -n c8y-messaging-service -- bin/pulsar-client consume -s test1 test1
```

Open another terminal and run the following: 
```
kubectl exec -it pulsar-broker-0 -n c8y-messaging-service -- bin/pulsar-client  produce -m "hello pulsar" test1
```

You should see the message being consumed in the first terminal console output.

8. To uninstall Pulsar messaging service,

   1. Uninstall helm deployment:
   ```
   helm uninstall pulsar
   ```

   2. Delete all PVs and claims:
   ```
   kubectl get pvc -n c8y-messaging-service --no-headers | awk '{ print $1 }' | grep 'pulsar' | xargs -I {} kubectl delete pvc {} -n c8y-messaging-service
   kubectl get pv -n c8y-messaging-service  --no-headers | awk '{ print $1 }' | xargs -I {} kubectl delete pv {} -n c8y-messaging-service
   ```
   
   3. Delete the local storage on kubernetes nodes where Apache Pulsar component is installed (under /var/zookeeper and /var/bookie)
   
   4. Delete the kubernetes secrets:
   ```
   kubectl delete secret c8y-messaging-secret -n <your-c8y-namespace-for-core-pods>
   kubectl delete secret c8y-secret -n c8y-messaging-service
   ```
   
   5. Delete the kubernetes namespace for messaging:
   ```
   kubectl delete namespace c8y-messaging-service
   ```
